#[repr(transparent)]pub struct CtrlTog(pub u32);Expand description
USB PHY General Control Register
Tuple Fields
0: u32Implementations
Sourceimpl CtrlTog
impl CtrlTog
Sourcepub const fn enotg_id_chg_irq(&self) -> bool
pub const fn enotg_id_chg_irq(&self) -> bool
Enable OTG_ID_CHG_IRQ.
Sourcepub const fn set_enotg_id_chg_irq(&mut self, val: bool)
pub const fn set_enotg_id_chg_irq(&mut self, val: bool)
Enable OTG_ID_CHG_IRQ.
Sourcepub const fn enhostdiscondetect(&self) -> bool
pub const fn enhostdiscondetect(&self) -> bool
For host mode, enables high-speed disconnect detector
Sourcepub const fn set_enhostdiscondetect(&mut self, val: bool)
pub const fn set_enhostdiscondetect(&mut self, val: bool)
For host mode, enables high-speed disconnect detector
Sourcepub const fn enirqhostdiscon(&self) -> bool
pub const fn enirqhostdiscon(&self) -> bool
Enables interrupt for detection of disconnection to Device when in high-speed host mode
Sourcepub const fn set_enirqhostdiscon(&mut self, val: bool)
pub const fn set_enirqhostdiscon(&mut self, val: bool)
Enables interrupt for detection of disconnection to Device when in high-speed host mode
Sourcepub const fn hostdiscondetect_irq(&self) -> bool
pub const fn hostdiscondetect_irq(&self) -> bool
Indicates that the device has disconnected in high-speed mode
Sourcepub const fn set_hostdiscondetect_irq(&mut self, val: bool)
pub const fn set_hostdiscondetect_irq(&mut self, val: bool)
Indicates that the device has disconnected in high-speed mode
Sourcepub const fn endevplugindetect(&self) -> bool
pub const fn endevplugindetect(&self) -> bool
For device mode, enables 200-KOhm pullups for detecting connectivity to the host.
Sourcepub const fn set_endevplugindetect(&mut self, val: bool)
pub const fn set_endevplugindetect(&mut self, val: bool)
For device mode, enables 200-KOhm pullups for detecting connectivity to the host.
Sourcepub const fn devplugin_polarity(&self) -> bool
pub const fn devplugin_polarity(&self) -> bool
For device mode, if this bit is cleared to 0, then it trips the interrupt if the device is plugged in
Sourcepub const fn set_devplugin_polarity(&mut self, val: bool)
pub const fn set_devplugin_polarity(&mut self, val: bool)
For device mode, if this bit is cleared to 0, then it trips the interrupt if the device is plugged in
Sourcepub const fn otg_id_chg_irq(&self) -> bool
pub const fn otg_id_chg_irq(&self) -> bool
OTG ID change interrupt. Indicates the value of ID pin changed.
Sourcepub const fn set_otg_id_chg_irq(&mut self, val: bool)
pub const fn set_otg_id_chg_irq(&mut self, val: bool)
OTG ID change interrupt. Indicates the value of ID pin changed.
Sourcepub const fn enotgiddetect(&self) -> bool
pub const fn enotgiddetect(&self) -> bool
Enables circuit to detect resistance of MiniAB ID pin.
Sourcepub const fn set_enotgiddetect(&mut self, val: bool)
pub const fn set_enotgiddetect(&mut self, val: bool)
Enables circuit to detect resistance of MiniAB ID pin.
Sourcepub const fn resumeirqsticky(&self) -> bool
pub const fn resumeirqsticky(&self) -> bool
Set to 1 will make RESUME_IRQ bit a sticky bit until software clear it
Sourcepub const fn set_resumeirqsticky(&mut self, val: bool)
pub const fn set_resumeirqsticky(&mut self, val: bool)
Set to 1 will make RESUME_IRQ bit a sticky bit until software clear it
Sourcepub const fn enirqresumedetect(&self) -> bool
pub const fn enirqresumedetect(&self) -> bool
Enables interrupt for detection of a non-J state on the USB line
Sourcepub const fn set_enirqresumedetect(&mut self, val: bool)
pub const fn set_enirqresumedetect(&mut self, val: bool)
Enables interrupt for detection of a non-J state on the USB line
Sourcepub const fn resume_irq(&self) -> bool
pub const fn resume_irq(&self) -> bool
Indicates that the host is sending a wake-up after suspend
Sourcepub const fn set_resume_irq(&mut self, val: bool)
pub const fn set_resume_irq(&mut self, val: bool)
Indicates that the host is sending a wake-up after suspend
Sourcepub const fn enirqdevplugin(&self) -> bool
pub const fn enirqdevplugin(&self) -> bool
Enables interrupt for the detection of connectivity to the USB line.
Sourcepub const fn set_enirqdevplugin(&mut self, val: bool)
pub const fn set_enirqdevplugin(&mut self, val: bool)
Enables interrupt for the detection of connectivity to the USB line.
Sourcepub const fn devplugin_irq(&self) -> bool
pub const fn devplugin_irq(&self) -> bool
Indicates that the device is connected
Sourcepub const fn set_devplugin_irq(&mut self, val: bool)
pub const fn set_devplugin_irq(&mut self, val: bool)
Indicates that the device is connected
Sourcepub const fn data_on_lradc(&self) -> bool
pub const fn data_on_lradc(&self) -> bool
Enables the LRADC to monitor USB_DP and USB_DM. This is for use in non-USB modes only.
Sourcepub const fn set_data_on_lradc(&mut self, val: bool)
pub const fn set_data_on_lradc(&mut self, val: bool)
Enables the LRADC to monitor USB_DP and USB_DM. This is for use in non-USB modes only.
Sourcepub const fn enutmilevel2(&self) -> bool
pub const fn enutmilevel2(&self) -> bool
Enables UTMI+ Level2. This should be enabled if needs to support LS device
Sourcepub const fn set_enutmilevel2(&mut self, val: bool)
pub const fn set_enutmilevel2(&mut self, val: bool)
Enables UTMI+ Level2. This should be enabled if needs to support LS device
Sourcepub const fn enutmilevel3(&self) -> bool
pub const fn enutmilevel3(&self) -> bool
Enables UTMI+ Level3
Sourcepub const fn set_enutmilevel3(&mut self, val: bool)
pub const fn set_enutmilevel3(&mut self, val: bool)
Enables UTMI+ Level3
Sourcepub const fn enirqwakeup(&self) -> bool
pub const fn enirqwakeup(&self) -> bool
Enables interrupt for the wakeup events.
Sourcepub const fn set_enirqwakeup(&mut self, val: bool)
pub const fn set_enirqwakeup(&mut self, val: bool)
Enables interrupt for the wakeup events.
Sourcepub const fn wakeup_irq(&self) -> bool
pub const fn wakeup_irq(&self) -> bool
Indicates that there is a wakeup event
Sourcepub const fn set_wakeup_irq(&mut self, val: bool)
pub const fn set_wakeup_irq(&mut self, val: bool)
Indicates that there is a wakeup event
Sourcepub const fn enauto_pwron_pll(&self) -> bool
pub const fn enauto_pwron_pll(&self) -> bool
Enables the feature to auto-enable the POWER bit of HW_CLKCTRL_PLLxCTRL0 if there is wakeup event if USB is suspended
Sourcepub const fn set_enauto_pwron_pll(&mut self, val: bool)
pub const fn set_enauto_pwron_pll(&mut self, val: bool)
Enables the feature to auto-enable the POWER bit of HW_CLKCTRL_PLLxCTRL0 if there is wakeup event if USB is suspended
Sourcepub const fn enautoclr_clkgate(&self) -> bool
pub const fn enautoclr_clkgate(&self) -> bool
Enables the feature to auto-clear the CLKGATE bit if there is wakeup event while USB is suspended
Sourcepub const fn set_enautoclr_clkgate(&mut self, val: bool)
pub const fn set_enautoclr_clkgate(&mut self, val: bool)
Enables the feature to auto-clear the CLKGATE bit if there is wakeup event while USB is suspended
Sourcepub const fn enautoclr_phy_pwd(&self) -> bool
pub const fn enautoclr_phy_pwd(&self) -> bool
Enables the feature to auto-clear the PWD register bits in USBPHYx_PWD if there is wakeup event while USB is suspended
Sourcepub const fn set_enautoclr_phy_pwd(&mut self, val: bool)
pub const fn set_enautoclr_phy_pwd(&mut self, val: bool)
Enables the feature to auto-clear the PWD register bits in USBPHYx_PWD if there is wakeup event while USB is suspended
Sourcepub const fn endpdmchg_wkup(&self) -> bool
pub const fn endpdmchg_wkup(&self) -> bool
Enables the feature to wakeup USB if DP/DM is toggled when USB is suspended
Sourcepub const fn set_endpdmchg_wkup(&mut self, val: bool)
pub const fn set_endpdmchg_wkup(&mut self, val: bool)
Enables the feature to wakeup USB if DP/DM is toggled when USB is suspended
Sourcepub const fn enidchg_wkup(&self) -> bool
pub const fn enidchg_wkup(&self) -> bool
Enables the feature to wakeup USB if ID is toggled when USB is suspended.
Sourcepub const fn set_enidchg_wkup(&mut self, val: bool)
pub const fn set_enidchg_wkup(&mut self, val: bool)
Enables the feature to wakeup USB if ID is toggled when USB is suspended.
Sourcepub const fn envbuschg_wkup(&self) -> bool
pub const fn envbuschg_wkup(&self) -> bool
Enables the feature to wakeup USB if VBUS is toggled when USB is suspended.
Sourcepub const fn set_envbuschg_wkup(&mut self, val: bool)
pub const fn set_envbuschg_wkup(&mut self, val: bool)
Enables the feature to wakeup USB if VBUS is toggled when USB is suspended.
Sourcepub const fn fsdll_rst_en(&self) -> bool
pub const fn fsdll_rst_en(&self) -> bool
Enables the feature to reset the FSDLL lock detection logic at the end of each TX packet.
Sourcepub const fn set_fsdll_rst_en(&mut self, val: bool)
pub const fn set_fsdll_rst_en(&mut self, val: bool)
Enables the feature to reset the FSDLL lock detection logic at the end of each TX packet.
Sourcepub const fn otg_id_value(&self) -> bool
pub const fn otg_id_value(&self) -> bool
Almost same as OTGID_STATUS in USBPHYx_STATUS Register
Sourcepub const fn set_otg_id_value(&mut self, val: bool)
pub const fn set_otg_id_value(&mut self, val: bool)
Almost same as OTGID_STATUS in USBPHYx_STATUS Register
Sourcepub const fn host_force_ls_se0(&self) -> bool
pub const fn host_force_ls_se0(&self) -> bool
Forces the next FS packet that is transmitted to have a EOP with LS timing
Sourcepub const fn set_host_force_ls_se0(&mut self, val: bool)
pub const fn set_host_force_ls_se0(&mut self, val: bool)
Forces the next FS packet that is transmitted to have a EOP with LS timing
Sourcepub const fn utmi_suspendm(&self) -> bool
pub const fn utmi_suspendm(&self) -> bool
Used by the PHY to indicate a powered-down state
Sourcepub const fn set_utmi_suspendm(&mut self, val: bool)
pub const fn set_utmi_suspendm(&mut self, val: bool)
Used by the PHY to indicate a powered-down state
Sourcepub const fn set_clkgate(&mut self, val: bool)
pub const fn set_clkgate(&mut self, val: bool)
Gate UTMI Clocks
Sourcepub const fn sftrst(&self) -> bool
pub const fn sftrst(&self) -> bool
Writing a 1 to this bit will soft-reset the USBPHYx_PWD, USBPHYx_TX, USBPHYx_RX, and USBPHYx_CTRL registers
Sourcepub const fn set_sftrst(&mut self, val: bool)
pub const fn set_sftrst(&mut self, val: bool)
Writing a 1 to this bit will soft-reset the USBPHYx_PWD, USBPHYx_TX, USBPHYx_RX, and USBPHYx_CTRL registers