nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Debug0Status

Struct Debug0Status 

#[repr(transparent)]
pub struct Debug0Status(pub u32);
UTMI Debug Status Register 0

Tuple Fields

0: u32

Implementations

Source

impl Debug0Status

pub const fn loop_back_fail_count(&self) -> u16

Running count of the failed pseudo-random generator loopback

pub const fn set_loop_back_fail_count(&mut self, val: u16)

Running count of the failed pseudo-random generator loopback

pub const fn utmi_rxerror_fail_count(&self) -> u16

Running count of the UTMI_RXERROR.

pub const fn set_utmi_rxerror_fail_count(&mut self, val: u16)

Running count of the UTMI_RXERROR.

pub const fn squelch_count(&self) -> u8

Running count of the squelch reset instead of normal end for HS RX.

pub const fn set_squelch_count(&mut self, val: u8)

Running count of the squelch reset instead of normal end for HS RX.