#[repr(transparent)]pub struct DebugTog(pub u32);Expand description
USB PHY Debug Register
Tuple Fields
0: u32Implementations
Sourceimpl DebugTog
impl DebugTog
Sourcepub const fn otgidpiolock(&self) -> bool
pub const fn otgidpiolock(&self) -> bool
Once OTG ID from USBPHYx_STATUS_OTGID_STATUS, use this to hold the value
Sourcepub const fn set_otgidpiolock(&mut self, val: bool)
pub const fn set_otgidpiolock(&mut self, val: bool)
Once OTG ID from USBPHYx_STATUS_OTGID_STATUS, use this to hold the value
Sourcepub const fn debug_interface_hold(&self) -> bool
pub const fn debug_interface_hold(&self) -> bool
Use holding registers to assist in timing for external UTMI interface.
Sourcepub const fn set_debug_interface_hold(&mut self, val: bool)
pub const fn set_debug_interface_hold(&mut self, val: bool)
Use holding registers to assist in timing for external UTMI interface.
Sourcepub const fn hstpulldown(&self) -> u8
pub const fn hstpulldown(&self) -> u8
Set bit 3 to 1 to pull down 15-KOhm on USB_DP line
Sourcepub const fn set_hstpulldown(&mut self, val: u8)
pub const fn set_hstpulldown(&mut self, val: u8)
Set bit 3 to 1 to pull down 15-KOhm on USB_DP line
Sourcepub const fn enhstpulldown(&self) -> u8
pub const fn enhstpulldown(&self) -> u8
Set bit 5 to 1 to override the control of the USB_DP 15-KOhm pulldown
Sourcepub const fn set_enhstpulldown(&mut self, val: u8)
pub const fn set_enhstpulldown(&mut self, val: u8)
Set bit 5 to 1 to override the control of the USB_DP 15-KOhm pulldown
Sourcepub const fn tx2rxcount(&self) -> u8
pub const fn tx2rxcount(&self) -> u8
Delay in between the end of transmit to the beginning of receive
Sourcepub const fn set_tx2rxcount(&mut self, val: u8)
pub const fn set_tx2rxcount(&mut self, val: u8)
Delay in between the end of transmit to the beginning of receive
Sourcepub const fn entx2rxcount(&self) -> bool
pub const fn entx2rxcount(&self) -> bool
Set this bit to allow a countdown to transition in between TX and RX.
Sourcepub const fn set_entx2rxcount(&mut self, val: bool)
pub const fn set_entx2rxcount(&mut self, val: bool)
Set this bit to allow a countdown to transition in between TX and RX.
Sourcepub const fn squelchresetcount(&self) -> u8
pub const fn squelchresetcount(&self) -> u8
Delay in between the detection of squelch to the reset of high-speed RX.
Sourcepub const fn set_squelchresetcount(&mut self, val: u8)
pub const fn set_squelchresetcount(&mut self, val: u8)
Delay in between the detection of squelch to the reset of high-speed RX.
Sourcepub const fn ensquelchreset(&self) -> bool
pub const fn ensquelchreset(&self) -> bool
Set bit to allow squelch to reset high-speed receive.
Sourcepub const fn set_ensquelchreset(&mut self, val: bool)
pub const fn set_ensquelchreset(&mut self, val: bool)
Set bit to allow squelch to reset high-speed receive.
Sourcepub const fn squelchresetlength(&self) -> u8
pub const fn squelchresetlength(&self) -> u8
Duration of RESET in terms of the number of 480-MHz cycles.
Sourcepub const fn set_squelchresetlength(&mut self, val: u8)
pub const fn set_squelchresetlength(&mut self, val: u8)
Duration of RESET in terms of the number of 480-MHz cycles.
Sourcepub const fn host_resume_debug(&self) -> bool
pub const fn host_resume_debug(&self) -> bool
Choose to trigger the host resume SE0 with HOST_FORCE_LS_SE0 = 0 or UTMI_SUSPEND = 1.
Sourcepub const fn set_host_resume_debug(&mut self, val: bool)
pub const fn set_host_resume_debug(&mut self, val: bool)
Choose to trigger the host resume SE0 with HOST_FORCE_LS_SE0 = 0 or UTMI_SUSPEND = 1.
Sourcepub const fn set_clkgate(&mut self, val: bool)
pub const fn set_clkgate(&mut self, val: bool)
Gate Test Clocks