nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

RxSet

Struct RxSet 

#[repr(transparent)]
pub struct RxSet(pub u32);
USB PHY Receiver Control Register

Tuple Fields

0: u32

Implementations

Source

impl RxSet

pub const fn envadj(&self) -> u8

The ENVADJ field adjusts the trip point for the envelope detector

pub const fn set_envadj(&mut self, val: u8)

The ENVADJ field adjusts the trip point for the envelope detector

pub const fn rsvd0(&self) -> bool

Reserved.

pub const fn set_rsvd0(&mut self, val: bool)

Reserved.

pub const fn disconadj(&self) -> u8

The DISCONADJ field adjusts the trip point for the disconnect detector: 000 = Trip-Level Voltage is 0

pub const fn set_disconadj(&mut self, val: u8)

The DISCONADJ field adjusts the trip point for the disconnect detector: 000 = Trip-Level Voltage is 0

pub const fn rsvd1(&self) -> u16

Reserved.

pub const fn set_rsvd1(&mut self, val: u16)

Reserved.

pub const fn rxdbypass(&self) -> bool

0 = Normal operation

pub const fn set_rxdbypass(&mut self, val: bool)

0 = Normal operation

pub const fn rsvd2(&self) -> u16

Reserved.

pub const fn set_rsvd2(&mut self, val: u16)

Reserved.