#[repr(transparent)]pub struct Status(pub u32);Expand description
USB PHY Status Register
Tuple Fields
0: u32Implementations
Sourceimpl Status
impl Status
Sourcepub const fn hostdiscondetect_status(&self) -> bool
pub const fn hostdiscondetect_status(&self) -> bool
Indicates that the device has disconnected while in high-speed host mode.
Sourcepub const fn set_hostdiscondetect_status(&mut self, val: bool)
pub const fn set_hostdiscondetect_status(&mut self, val: bool)
Indicates that the device has disconnected while in high-speed host mode.
Sourcepub const fn devplugin_status(&self) -> bool
pub const fn devplugin_status(&self) -> bool
Indicates that the device has been connected on the USB_DP and USB_DM lines.
Sourcepub const fn set_devplugin_status(&mut self, val: bool)
pub const fn set_devplugin_status(&mut self, val: bool)
Indicates that the device has been connected on the USB_DP and USB_DM lines.
Sourcepub const fn otgid_status(&self) -> bool
pub const fn otgid_status(&self) -> bool
Indicates the results of ID pin on MiniAB plug
Sourcepub const fn set_otgid_status(&mut self, val: bool)
pub const fn set_otgid_status(&mut self, val: bool)
Indicates the results of ID pin on MiniAB plug
Sourcepub const fn resume_status(&self) -> bool
pub const fn resume_status(&self) -> bool
Indicates that the host is sending a wake-up after suspend and has triggered an interrupt.
Sourcepub const fn set_resume_status(&mut self, val: bool)
pub const fn set_resume_status(&mut self, val: bool)
Indicates that the host is sending a wake-up after suspend and has triggered an interrupt.