#[repr(transparent)]pub struct Debug0Status(pub u32);Expand description
UTMI Debug Status Register 0
Tuple Fields
0: u32Implementations
Sourceimpl Debug0Status
impl Debug0Status
Sourcepub const fn loop_back_fail_count(&self) -> u16
pub const fn loop_back_fail_count(&self) -> u16
Running count of the failed pseudo-random generator loopback
Sourcepub const fn set_loop_back_fail_count(&mut self, val: u16)
pub const fn set_loop_back_fail_count(&mut self, val: u16)
Running count of the failed pseudo-random generator loopback
Sourcepub const fn utmi_rxerror_fail_count(&self) -> u16
pub const fn utmi_rxerror_fail_count(&self) -> u16
Running count of the UTMI_RXERROR.
Sourcepub const fn set_utmi_rxerror_fail_count(&mut self, val: u16)
pub const fn set_utmi_rxerror_fail_count(&mut self, val: u16)
Running count of the UTMI_RXERROR.
Sourcepub const fn squelch_count(&self) -> u8
pub const fn squelch_count(&self) -> u8
Running count of the squelch reset instead of normal end for HS RX.
Sourcepub const fn set_squelch_count(&mut self, val: u8)
pub const fn set_squelch_count(&mut self, val: u8)
Running count of the squelch reset instead of normal end for HS RX.